@@ -1,12 +1,12 @@
 #' Search, extract and format data from the World Bank's World Development Indicators
-#' 
+#'
 #' The \code{WDI} function provides convenient access to over 40 databases
 #' hosted by the World Bank, including the World Development Indicators (WDI),
 #' International Debt Statistics, Doing Business, Human Capital Index, and
 #' Sub-national poverty indicators.  For fast searching, the WDI package ships
 #' with a local list of available data series. This local list can be updated
-#' to the latest version using the \code{WDIcache} function. 
-#' 
+#' to the latest version using the \code{WDIcache} function.
+#'
 #' @name WDI-package
 #' @aliases WDI-package
 #' @title Search, extract, and format data from the World Bank
@@ -14,6 +14,6 @@
 #' @references
 #'     \url{http://arelbundock.com}
 #'     \url{https://github.com/vincentarelbundock/WDI}
-#' @docType package
+#' @noRd
 #' @keywords package
-NULL
+"_PACKAGE"
